Learn R Programming

ICAOD (version 0.9.2)

FIM_logisitic_1par: Fisher information matrix for the one-parameter logistic model (1PL or Rasch model).

Description

The mean of response variable is $$f(x, a) = 1/(1 + \exp(-(x - a))).$$ This function returns Fisher information for the design \(\xi\) that is $$M(\xi; a) = \sum_{i = 1}^kw_iM(x_i, a).$$ Here \(M(x, a)\) is \(g(x-a)\), where \(g(z) = \frac{\exp(z)}{(1 + \exp(z))^2}\). denotes the standard logistic density.

Usage

FIM_logisitic_1par(x, w, param)

Arguments

x

vector of design points. In IRT x is the person ability parameter.

w

vector of design weight. Its length must be equal to the length of x and sum(w) should be 1.

param

parameter \(a\). In IRT, it is called difficulty parameter.

Value

Fisher information as a one by one matrix.

Details

The locally optimal design is a one point design with \(x^* = a\) and provides a value of \(M(\xi^*, a) = 1/4\) for the information.

References

Grasshoff, U., Holling, H., & Schwabe, R. (2012). Optimal designs for the Rasch model. Psychometrika, 77(4), 710-723.

See Also

Other FIM: FIM_comp_inhibition, FIM_emax_3par, FIM_exp_2par, FIM_exp_3par, FIM_logistic_4par, FIM_logistic, FIM_loglin, FIM_michaelis, FIM_mixed_inhibition, FIM_noncomp_inhibition, FIM_power_logistic, FIM_uncomp_inhibition