Learn R Programming

ICAOD (version 0.9.2)

FIM_logistic: Fisher information matrix for the two-parameter logistic (2PL) model.

Description

The mean of response variable is $$f(x, \bold{\theta}) = \frac{1}{(1 + \exp(-b (x - a)))},$$ where \(\bold{\theta} = (a, b)\).

Usage

FIM_logistic(x, w, param)

Arguments

x

vector of design points. In IRT, \(x\) is the person ability parameter.

w

vector of design weight. Its length must be equal to the length of x and sum(w) should be 1.

param

vector of model parameters \(\bold{\theta} = (a, b)\). In IRT parameter \(a\) is the item difficulty parameter and parameter \(b\) is the item discrimination parameter.

Value

Fisher information matrix.

Details

There is no closed-form for the locally optimal design. For minimax and standardized D-optimal design, the optimal design is symmetric around point \((a^L + a^U)/2\) where \(a^L\) and \(a^U\) are the lower bound and upper bound for parameter \(a\), respectively. In mica, options sym and sym_point in control can be used to make the search for the optimal design easier.

See Also

Other FIM: FIM_comp_inhibition, FIM_emax_3par, FIM_exp_2par, FIM_exp_3par, FIM_logisitic_1par, FIM_logistic_4par, FIM_loglin, FIM_michaelis, FIM_mixed_inhibition, FIM_noncomp_inhibition, FIM_power_logistic, FIM_uncomp_inhibition