FIM_loglin: Fisher Information Matrix for the Mixed Inhibition Model

View source: R/RcppExports.R

FIM_loglinR Documentation

Fisher Information Matrix for the Mixed Inhibition Model

Description

It provides the cpp function for the FIM for the model ~theta0 + theta1* log(x + theta2).

Usage

FIM_loglin(x, w, param)

Arguments

x

Vector of design points.

w

Vector of design weight. Its length must be equal to the length of x and sum(w) = 1.

param

Vector of values for the model parameters c(theta0, theta1, theta2).

Details

The FIM of this model does not depend on the parameter theta0.

Value

Fisher information matrix.

References

Dette, H., Kiss, C., Bevanda, M., & Bretz, F. (2010). Optimal designs for the EMAX, log-linear and exponential models. Biometrika, 97(2), 513-518.


ICAOD documentation built on Feb. 3, 2026, 5:07 p.m.

Related to FIM_loglin in ICAOD...