| FIM_mixed_inhibition | R Documentation |
It provides the cpp function for FIM for the model ~ V*S/(Km * (1 + I/Kic)+ S * (1 + I/Kiu))
FIM_mixed_inhibition(S, I, w, param)
S |
Vector of |
I |
Vector of |
w |
Vector of design weight. Its length must be equal to the length of |
param |
Vector of values for the model parameters |
The optimal design does not depend on parameter V.
Fisher information matrix of design.
Bogacka, B., Patan, M., Johnson, P. J., Youdim, K., & Atkinson, A. C. (2011). Optimum design of experiments for enzyme inhibition kinetic models. Journal of biopharmaceutical statistics, 21(3), 555-572.
FIM_mixed_inhibition(S = c(30, 3.86, 30, 4.60),
I = c(0, 0, 5.11, 4.16), w = rep(.25, 4),
param = c(1.5, 5.2, 3.4, 5.6))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.