Learn R Programming

ICAOD (version 0.9.1)

FIM_uncomp_inhibition: Fisher information matrix for the uncompetitive inhibition Michaelis-Menten model.

Description

The mean velocity of the reaction rate is $$\eta = \frac{VS}{(K_m + S(1 + \frac{I}{K_{iu}}))}.$$ Here, $S$ is the substrate concentration, $I$ is the inhibitor concentration, $V$ is the maximum velocity of the enzyme, $Kiu$ is the dissociation constants and $Km$ is the Michaelis-Menten constant. Any design point is of the form $(S, I)$.

Usage

FIM_uncomp_inhibition(S, I, w, param)

Arguments

S
vector of S component of design points. S is the substrate concentration.
I
vector of I component of design points. I is the inhibitor concentration.
w
vector of corresponding weights for each design point. Its length must be equal to the length of I and S, and sum(w) should be 1.
param
vector of model parameters $(V, Km, Kiu)$.

Value

Fisher information matrix.

Details

The model has an analytical solution for the locally D-optimal design. See Bogacka et al. (2011) for details. The optimal design does not depend on parameter $V$.

References

Bogacka, B., Patan, M., Johnson, P. J., Youdim, K., & Atkinson, A. C. (2011). Optimum design of experiments for enzyme inhibition kinetic models. Journal of biopharmaceutical statistics, 21(3), 555-572.

See Also

Other FIM: FIM_comp_inhibition, FIM_emax_3par, FIM_exp_2par, FIM_exp_3par, FIM_logisitic_1par, FIM_logistic_4par, FIM_logistic, FIM_loglin, FIM_michaelis, FIM_mixed_inhibition, FIM_noncomp_inhibition, FIM_power_logistic