Learn R Programming

ICAOD (version 0.9.1)

equivalence_multiple: Checking the optimality of a given design with respect to the multi-objective criterion for the 4-parameter logisitic model.

Description

The equivalence theorem states that for a given vector of weights $\lambda = (\lambda1, \lambda2, \lambda3)$, the design $\xi_\lambda$ is the multi-objective optimal design if and only if for all does $x$ in the dose range $\chi$ (design space) $$d(x, \xi_\lambda) \leq 0$$ with equality when $x$ is a dose level of design $\xi_\lambda$. See Eq. 6 of Hyun and Wong (2015) for the details.

Usage

equivalence_multiple(x, w, lx, ux, param, lambda, delta, maxeval_equivalence = 6000, plot_sensitivity = TRUE)

Arguments

x
a vector of design points. When design space is multi-dimensional then x should be filled dimension by dimension. See "Examples".
w
a vector of design weights.
lx
lower bound of the design space $\chi$.
ux
upper bound of the design space $\chi$.
param
initial guess for parameters $\Theta = (\theta1, \theta2, \theta3, \theta4)$.
lambda
user select weights, where $\lambda1$ is the weight for estimating parameters, $\lambda2$ is the weignt for estimating median effective dose level (ED50), and $\lambda3$ is the weight for estimating minimum effective dose level (MED).
delta
numeric, predetermined clinically significant effect to define the MED.
maxeval_equivalence
maximum number of evaulations (maxeval) that will be passed to optimization function directL to find the maximum of the sensitivity function required for calculating DLB. See "Details" of equivalence.
plot_sensitivity
logical; sensitivity should be plotted? see "Details" of equivalence.

Value

an object of class 'equivalence' that is a list contains:

Details

When $\lambda1 = 1$, the function checks the equivalence theorem with respect to the c-optimality criterion for estimating ED50. When $\lambda3 = 1$, it checks the equivalence theorem with respect to the c-optimality criterion for estimating MED. In both cases, due to the tolerance issue for computing the generalized inverse, the results may not be true. Therefore, this function should only be used for multiple-objective optimal design $\lambda_1 \neq 0$ and $\lambda1 and \lambda2 are not equal to 0.$

The tolerance for finding the general inverse is set to .Machine$double.xmin.

See Also

equivalence and equivalence_on_average.

Examples

Run this code
## verfying the design in Table 2 of Hyun and Wong (2015), first row, fisrt column.
Theta1 <- c(1.563, 1.790, 8.442, 0.137)
equivalence_multiple (x = c(log(.001), -5.21, -4.08, log(1000)),
                     w = c(.25, .25, .25, .25),
                     lx = log(.001), ux = log(1000),
                     param = Theta1,
                     lambda = c(1, 0, 0),
                     delta = -1)


Run the code above in your browser using DataLab