Learn R Programming

ICAOD (version 0.9.1)

equivalence_on_average: Checking the optimality of a given design with respect to the optim-on-the-average criterion by equivalence theorem.

Description

Let $\Theta$ be the set of plausible parameter values and weighted by a probability measure $\pi$, the measure having support in the parameter space $\Theta$, and $\Psi(\xi, \theta) =|M(\xi, \theta)|$. A design $\xi*$ is optimum-on-the-average with respect to prior $\pi$ if the following inequality holds for all $x belong to \chi$ $$c(\boldsymbol{x}, \pi, \xi^*) = \int_{\pi} tr M^{-1}(\xi^*, \theta)I(\boldsymbol{x}, \theta)\pi(\theta) d(\theta)-p \leq 0,$$ with equality at all support points of $\xi*$. Here, $p$ is the number of model parameters.

Usage

equivalence_on_average(fimfunc, x, w, lx, ux, prior, param, maxeval_equivalence = 6000, plot_sensitivity = TRUE, ...)

Arguments

fimfunc
Fisher information matrix. Can be the name of the Fisher information matrix from FIM family functions available in this package as a character string or a function that returns the information matrix. See "Details" of mica.
x
a vector of design points. When design space is multi-dimensional then x should be filled dimension by dimension. See "Examples" of mica.
w
a vector of design weights.
lx
lower bound of the design space $\chi$.
ux
upper bound of the design space $\chi$.
prior
a vector of probability measure $\pi$.
param
a matrix contains the value of parameters, i.e. support of $\pi$. Every row is one parameter. The number of its rows must be equal to the length of prior.
maxeval_equivalence
maximum number of evaulations (maxeval) that will be passed to optimization function directL to find the maximum of the sensitivity function required for calculating DLB. See "Details" of equivalence.
plot_sensitivity
logical; sensitivity should be plotted? see "Details" of equivalence.
...
further argument to be passed to fimfunc.

Value

an object of class 'equivalence' that is a list contains:

See Also

equivalence and equivalence_multiple.

Examples

Run this code
equivalence_on_average(fimfunc ="FIM_logistic",lx = -5, ux = 5, x = c(0.2603688, 1, 1.739631),
                      w = c(0.2750147, 0.4499705, 0.2750148),  prior = c(.25, .25, .25, .25),
                      param =  matrix(c(0.5, 1.5, 0.5, 1.5, 4.0, 4.0, 5.0, 5.0), 4, 2))

Run the code above in your browser using DataLab