Learn R Programming

ICAOD (version 0.9.2)

plot.ICA: Plot method for an object of class "ICA".

Description

Plot method for an object of class "ICA".

Usage

# S3 method for ICA
plot(x, iter = NULL, sensitivity = TRUE,
  print_equivalence = FALSE, ...)

Arguments

x

an object of class "ICA".

iter

iteration. if NULL, is set to the last iteration.

sensitivity

logical; if TRUE the best design in iteration iter is checked by equivalence theorem.

print_equivalence

logical; if TRUE the result of checking by equivalence theorem will be printed. Only applicable when sensitivity = TRUE.

...

argument with no further use.

See Also

mica, multica_4pl and ave