Learn R Programming

ICAOD (version 0.9.9)

plot.bayes: Plotting bayes Objects

Description

This function plots the evolution of the ICA algorithm (iteration vs the best (minimum) criterion value at each iteration) and also verifies the optimality of the last obtained design using the general equivalence theorem. It plots the sensitivity function and calculates the ELB for the best design generated at iteration number iter.

Usage

# S3 method for bayes
plot(x, iter = NULL, sensitivity = TRUE,
  calculate_criterion = FALSE, sens.control = list(),
  sens.bayes.control = list(), crt.bayes.control = list(),
  silent = FALSE, plot_3d = c("lattice", "rgl"), evolution = FALSE,
  ...)

Arguments

x

An object of class bayes.

iter

Iteration number. if NULL (default), it will be set to the last iteration.

sensitivity

Logical. If TRUE (default), the general equivalence theorem is used to check the optimality if the best design in iteration number iter and the sensitivity function will be plotted.

calculate_criterion

Logical. Re-calculate the Bayesian criterion value (maybe with a set of new tuning parameters to be sure of the accuracy of the integral approximation)? Defaults to FALSE. See 'Details'.

sens.control

Control Parameters for Calculating the ELB. For details, see the function sens.control.

sens.bayes.control

Control parameters to verify general equivalence theorem. For details, see sens.bayes.control. If NULL (default), it will be set to the tuning parameters used to create object x.

crt.bayes.control

Control parameters to approximate the integration in the Bayesian criterion at a given design. For details, see crt.bayes.control. If NULL (default), it will be set to the tuning parameters used to create object x.

silent

Do not print anything? Defaults to FALSE.

plot_3d

Which package should be used to plot the sensitivity function for two-dimensional design space. Defaults to plot_3d = "lattice". Only applicable when sensitivity = TRUE.

evolution

Plot Evolution? Defaults to FALSE.

...

Argument with no further use.

Details

In addition to verifying the general equivalence theorem, this function makes it possible to re-calculate the criterion value for the output designs using a new (say, more conservative) set of tuning parameters. This is useful for Bayesian optimal designs to assess the robustness of the criterion value with respect to different values of the tuning parameters. To put it simple, for Bayesian generated designs, the user can re-calculate the criterion value for the output design (best design generated in iter) with different values for maxEval and tol in crt.bayes.control to verify that the function hcubature approximates the integrals to an user-acceptable accuracy. The same also applies for the quadrature methods using different number of nodes.

See Also

bayes, bayescomp