This function returns two lists each corresponds
to an implemented integration method for approximating the integrals
in the sensitivity (derivative) functions for Bayesian criteria.
Moreover, it contains a list of nloptr control parameters to find maximum of the sensitivity (derivative) function over the design space,
used to calculate the efficiency lower bound (ELB).
sens.bayes.control(cubature = list(tol = 1e-05, maxEval = 50000, absError
= 0), quadrature = list(type = NULL, level = NULL, ndConstruction =
"product", level.trans = FALSE), x0 = NULL, optslist = list(stopval =
-Inf, algorithm = "NLOPT_GN_DIRECT_L", xtol_rel = 1e-08, ftol_rel =
1e-10, maxeval = 2000), ...)A list that will be passed to the arguments of the hcubature function. See 'Details' of crt.bayes.control.
A list that will be passed to the arguments of the createNIGrid function. See 'Details' of crt.bayes.control.
Vector of starting values for maximizing the sensitivity (derivative) function over the design space \(x\).
It will be passed to the optimization function nloptr.
A list will be passed to opts argument of the function nloptr to find the maximum of the sensitivity function over the design space. See 'Details'.
A list of three lists each contains the control parameters for verifying the general equivalence theorem with respect to the Bayesian optimality criteria.
ELB is a measure of proximity of a design to the optimal design without knowing the latter.
Given a design, let \(\epsilon\) be the global maximum
of the sensitivity (derivative) function with respect the vector of the model predictors \(x\) over the design space.
ELB is given by $$ELB = p/(p + \epsilon),$$
where \(p\) is the number of model parameters. Obviously,
calculating ELB requires finding \(\epsilon\) and therefore,
a maximization problem to be solved. The function nloptr
is used here to solve this maximization problem. The arguments x0 and optslist
will be passed to this function as follows:
Argument x0 provides the user initial values for this maximization problem
and will be passed to the argument with the same name
in the function nloptr.
Argument optslist is a list and it will be passed to the argument opts of the function nloptr.
The most important components of optslist are:
stopvalStop minimization when an objective value <= stopval is found. Setting stopval to -Inf disables this stopping criterion (default).
algorithmDefaults to NLOPT_GN_DIRECT_L. DIRECT-L is a deterministic-search algorithm based on systematic division of the search domain into smaller and smaller hyperrectangles.
xtol_relStop when an optimization step (or an estimate of the optimum) changes every parameter by less than xtol_rel multiplied by the absolute value of the parameter. Criterion is disabled if xtol_rel is non-positive. Defaults to 1e-8.
ftol_relStop when an optimization step (or an estimate of the optimum) changes the objective function value by less than ftol_rel multiplied by the absolute value of the function value. Criterion is disabled if ftol_rel is non-positive. Defaults to 1e-10.
maxevalStop when the number of function evaluations exceeds maxeval. Criterion is disabled if maxeval is non-positive. Defaults to 6000. See 'Note' on when to change its value.
More details are available by the function nloptr.print.options() in package nloptr.
# NOT RUN {
sens.bayes.control()
sens.bayes.control(cubature = list(maxEval = 50000))
sens.bayes.control(optslist = list(maxeval = 3000))
sens.bayes.control(quadrature = list(level = 4))
# }
Run the code above in your browser using DataLab