Learn R Programming

ICAOD (version 0.9.9)

update.bayes: Updating an Object of Class bayes

Description

Runs the ICA optimization algorithm on an object of class bayes for more number of iterations and updates the results.

Usage

# S3 method for bayes
update(object, iter, ...)

Arguments

object

An object of class bayes.

iter

Number of iterations.

...

An argument of no further use.

See Also

bayes