update.minimax: Updating an Object of Class minimax
Description
Runs the ICA optimization algorithm on an object of class minimax for more number of iterations and updates the results.
Usage
# S3 method for minimax
update(object, iter, ...)
Arguments
object
An object of class minimax.
...
An argument of no further use.