The mean of the response variable is $$f(x, \bold{\theta}) = \frac{\theta_1}{1 + \exp(\theta_2 x + \theta_3)} + \theta_4,$$ where \(\bold{\theta} = (\theta_1, \theta_2, \theta_3, \theta_4)\).
FIM_logistic_4par(x, w, param)vector of design points.
vector of design weight. Its length must be equal to the length of x and sum(w) should be 1.
vector of model parameters \(\bold{\theta} = (\theta_1, \theta_2, \theta_3, \theta_4)\).
Fisher information matrix.
The fisher information matrix does not depend on \(\theta_4\). There is no analytical solution for the locally D-optimal design for this model.
Other FIM: FIM_comp_inhibition,
FIM_emax_3par, FIM_exp_2par,
FIM_exp_3par,
FIM_logisitic_1par,
FIM_logistic, FIM_loglin,
FIM_michaelis,
FIM_mixed_inhibition,
FIM_noncomp_inhibition,
FIM_power_logistic,
FIM_uncomp_inhibition