Plot method for an object of class "ICA".
# S3 method for ICA
plot(x, iter = NULL, sensitivity = TRUE,
print_equivalence = FALSE, ...)an object of class "ICA".
iteration. if NULL, is set to the last iteration.
logical; if TRUE the best design in iteration iter is checked by equivalence theorem.
logical; if TRUE the result of checking by equivalence theorem will be printed.
Only applicable when sensitivity = TRUE.
argument with no further use.
mica, multica_4pl and ave