"plot"(x, iter = NULL, sensitivity = TRUE, print_equivalence = FALSE, ...)NULL, is set to the last iteration.TRUE the best design in iteration iter is checked by equivalence theorem.TRUE the result of checking by equivalence theorem will be printed.
Only applicable when sensitivity = TRUE.mica